@@ -666,5 +666,8 @@ class ProxySQL_Admin {
 	bool ProxySQL_Test___CA_Certificate_Load_And_Verify(uint64_t* duration, int cnt, const char* cacert, const char* capath);
 #endif
 	friend void admin_session_handler(MySQL_Session *sess, void *_pa, PtrSize_t *pkt);
+
+	// FLUSH LOGS
+	void flush_logs();
 };
 #endif /* __CLASS_PROXYSQL_ADMIN_H */
