@@ -211,4 +211,12 @@ SQLite3_result* proxysql_get_message_stats(bool reset=false);
  */
 void proxysql_init_debug_prometheus_metrics();
 
+
+/**
+ * @brief Set or unset if Admin has debugdb_disk fully initialized
+ */
+void proxysql_set_admin_debugdb_disk(SQLite3DB *_db);
+
+void proxysql_set_admin_debug_output(unsigned int _do);
+
 #endif
