@@ -10,15 +10,13 @@
 #define DIGEST_STATS_FAST_MINSIZE   100000
 #define DIGEST_STATS_FAST_THREADS   4
 
-
+#include "../deps/json/json.hpp"
 
 
 #include "khash.h"
 KHASH_MAP_INIT_STR(khStrInt, int)
 
-typedef std::unordered_map<std::uint64_t, void *> umap_query_digest;
-typedef std::unordered_map<std::uint64_t, char *> umap_query_digest_text;
-
+#include "proxysql_typedefs.h"
 
 #define WUS_NOT_FOUND   0	// couldn't find any filter
 #define WUS_OFF         1	// allow the query
@@ -206,6 +204,20 @@ class Query_Processor_Output {
 			free(comment);
 		}
 	}
+	void get_info_json(nlohmann::json& j) {
+		j["create_new_connection"] = create_new_conn;
+		j["reconnect"] = reconnect;
+		j["sticky_conn"] = sticky_conn;
+		j["cache_timeout"] = cache_timeout;
+		j["cache_ttl"] = cache_ttl;
+		j["delay"] = delay;
+		j["destination_hostgroup"] = destination_hostgroup;
+		j["firewall_whitelist_mode"] = firewall_whitelist_mode;
+		j["multiplex"] = multiplex;
+		j["timeout"] = timeout;
+		j["retries"] = retries;
+		j["max_lag_ms"] = max_lag_ms;
+	}
 };
 
 static char *commands_counters_desc[MYSQL_COM_QUERY___NONE];
