@@ -9,6 +9,7 @@
 #endif
 
 #include <sstream>
+#include "mysqld_error.h"
 
 
 static inline char is_digit(char c) {
@@ -17,6 +18,23 @@ static inline char is_digit(char c) {
 	return 0;
 }
 
+var_track_err_st perm_track_errs[] {
+	// ERROR 1210 (HY000): Variable not supported in combination with Galera:
+	// - Changed by MySQL, previously 'ER_UNKNOWN_SYSTEM_VARIABLE'
+	{ ER_WRONG_ARGUMENTS, "sql_generate_invisible_primary_key" }
+};
+
+bool is_perm_track_err(int err, const char* varname) {
+	const size_t count = sizeof(perm_track_errs) / sizeof(var_track_err_st);
+
+	for (size_t i = 0; i < count; i++) {
+		if (perm_track_errs[i].err == err && (strcasecmp(varname, perm_track_errs[i].name) == 0)) {
+			return true;
+		}
+	}
+	return false;
+}
+
 #include "proxysql_find_charset.h"
 
 verify_var MySQL_Variables::verifiers[SQL_NAME_LAST_HIGH_WM];
