@@ -4,8 +4,8 @@
 #include <string>
 #include <stdio.h>
 
-#include <mysql.h>
-#include <mysql/mysqld_error.h>
+#include "mysql.h"
+#include "mysqld_error.h"
 
 #include "proxysql_utils.h"
 #include "tap.h"
