@@ -3,7 +3,7 @@
 #include <stdio.h>
 #include <cstring>
 #include <unistd.h>
-#include <mysql.h>
+#include "mysql.h"
 
 #include "tap.h"
 #include "command_line.h"
