@@ -7,7 +7,8 @@
 #include <vector>
 #include <string>
 #include <stdio.h>
-#include <mysql.h>
+#include "mysql.h"
+#include "mysqld_error.h"
 
 #include "tap.h"
 #include "command_line.h"
