@@ -17,7 +17,7 @@
 #include <iostream>
 #include <thread>
 
-#include <mysql.h>
+#include "mysql.h"
 
 #include "proxysql_utils.h"
 #include "tap.h"
