@@ -12,7 +12,6 @@
 #include <string>
 #include <stdio.h>
 #include <unistd.h>
-#include <vector>
 #include "mysql.h"
 
 #include "tap.h"
@@ -49,72 +48,6 @@ static int wait_for_mysql(MYSQL *mysql, int status) {
 }
 #endif
 
-/**
- * @brief Function is required to be duplicated in the test because multiple compilations using
- *   'libmysqlclient' and 'libmariadbclient'. TODO: Being able to share helper functions targetting different
- *   connector libraries between tap tests.
- */
-int add_more_rows_test_sbtest1(int num_rows, MYSQL *mysql, bool sqlite) {
-	std::random_device rd;
-	std::mt19937 mt(rd());
-	std::uniform_int_distribution<int> dist(0.0, 9.0);
-
-	diag("Creating %d rows in sbtest1", num_rows);
-	while (num_rows) {
-		std::stringstream q;
-
-		if (sqlite==false) {
-		q << "INSERT INTO test.sbtest1 (k, c, pad) values ";
-		} else {
-			q << "INSERT INTO sbtest1 (k, c, pad) values ";
-		}
-		bool put_comma = false;
-		int i=0;
-		unsigned int cnt=5+rand()%50;
-		if (cnt > num_rows) cnt = num_rows;
-		for (i=0; i<cnt ; ++i) {
-			num_rows--;
-			int k = dist(mt);
-			std::stringstream c;
-			for (int j=0; j<10; j++) {
-				for (int k=0; k<11; k++) {
-					c << dist(mt);
-				}
-				if (j<9)
-					c << "-";
-			}
-			std::stringstream pad;
-			for (int j=0; j<5; j++) {
-				for (int k=0; k<11; k++) {
-					pad << dist(mt);
-				}
-				if (j<4)
-					pad << "-";
-			}
-			if (put_comma) q << ",";
-			if (!put_comma) put_comma=true;
-			q << "(" << k << ",'" << c.str() << "','" << pad.str() << "')";
-		}
-		MYSQL_QUERY(mysql, q.str().c_str());
-		diag("Inserted %d rows ...", i);
-	}
-	diag("Done!");
-	return 0;
-}
-
-/**
- * @brief Function is required to be duplicated in the test because multiple compilations using
- *   'libmysqlclient' and 'libmariadbclient'. TODO: Being able to share helper functions targetting different
- *   connector libraries between tap tests.
- */
-int create_table_test_sbtest1(int num_rows, MYSQL *mysql) {
-	MYSQL_QUERY(mysql, "CREATE DATABASE IF NOT EXISTS test");
-	MYSQL_QUERY(mysql, "DROP TABLE IF EXISTS test.sbtest1");
-	MYSQL_QUERY(mysql, "CREATE TABLE if not exists test.sbtest1 (`id` int(10) unsigned NOT NULL AUTO_INCREMENT, `k` int(10) unsigned NOT NULL DEFAULT '0', `c` char(120) NOT NULL DEFAULT '', `pad` char(60) NOT NULL DEFAULT '',  PRIMARY KEY (`id`), KEY `k_1` (`k`))");
-
-	return add_more_rows_test_sbtest1(num_rows, mysql);
-}
-
 std::string select_query = {
 	"SELECT /*+ MAX_EXECUTION_TIME(10) */ COUNT(*) FROM test.sbtest1 a JOIN test.sbtest1 b WHERE (a.id+b.id)%2"
 };
