@@ -4,7 +4,7 @@
 #include <cstring>
 #include <set>
 #include <unistd.h>
-#include <mysql.h>
+#include "mysql.h"
 
 #include "tap.h"
 #include "command_line.h"
